make_crumbs

Function make_crumbs 

fn make_crumbs(
    dir_path: &str,
    is_blob: bool,
    filename: Option<&str>,
) -> Vec<Crumb>
Build breadcrumb entries for a tree or blob page.

dir_path is the path to the containing directory (e.g. "src" for src/main.rs). depth is derived from dir_path internally.